@@ -2,11 +2,10 @@ from pathlib import Path
 
 import numpy as np
 import numpy.ma as ma
-import pandas as pd
 from numpy.ma.core import MaskedArray
 from scipy.io.arff import loadarff
 
-from loadmydata.container import DataSet
+from sklearn.utils import Bunch
 from loadmydata.padding import pad_at_the_end
 from loadmydata.utils import (
     download_from_remote_uea_ucr,
@@ -25,14 +24,15 @@ def load_Xy_from_arff(data_path: Path) -> (MaskedArray, np.ndarray):
     # load from downloaded (or cached) files
     data, meta = loadarff(data_path)
     names = meta.names()
+    target = names[-1]
     # are the data multivariate or univariate?
     is_multivariate = len(names) == 2
     is_univariate = not is_multivariate
     # load y, the target variable
-    y = data["target"].view().astype(str)
+    y = data[target].view().astype(str)
     # load X, the attributes
     if is_univariate:
-        keep_col = [col for col in names if col != "target"]
+        keep_col = [col for col in names if col != target]
         X_raw = data[keep_col].view()
     elif is_multivariate:
         X_raw = data[names[0]].view()
@@ -53,7 +53,7 @@ def load_Xy_from_arff(data_path: Path) -> (MaskedArray, np.ndarray):
     return X, y
 
 
-def load_uea_ucr_data(name: str) -> DataSet:
+def load_uea_ucr_data(name: str) -> Bunch:
     """Return data for the given data set.
 
     The data are contained in a `DataSet` instance.
@@ -66,7 +66,7 @@ def load_uea_ucr_data(name: str) -> DataSet:
         name (str): data set's name, e.g. `ArrowHead` (case-sensitive).
 
     Returns:
-        [loadmydata.container.DataSet]: X_train, X_test, y_train, y_test, url
+        [sklearn.util.Bunch]: (dict-like) X_train, X_test, y_train, y_test, url
             and description of the data set.
     """
 
@@ -84,7 +84,7 @@ def load_uea_ucr_data(name: str) -> DataSet:
     with (open(data_path_description, encoding="ISO-8859-1")) as f:
         description = f.read()
 
-    return DataSet(
+    return Bunch(
         X_train=X_train,
         y_train=y_train,
         X_test=X_test,
